#
# SPDX-FileCopyrightText: Copyright (c) 2025 provide.io llc. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
#

"""TODO: Add module docstring."""

from pyvider.capabilities.base import BaseCapability
from pyvider.capabilities.decorators import register_capability, requires_capability

__all__ = [
    "BaseCapability",
    "register_capability",
    "requires_capability",
]

# 🐍🏗️🔚
